
.. blogpost::
    :title: Discontinued module with Python 3.5
    :keywords: Python 3.5, modules
    :date: 2016-03-12
    :categories: module

    I updated the list of module not available on Python 3.5
    described here :ref:`l-blog-pymy-2015-10-28`::

        cgal_bindings
        libpython
        llvmpy
        py2exe
        PySide

    I removed them of the list of installed packages on Python 3.5.
